searchData={"items":[{"type":"module","title":"CookieMonster","doc":"A simple HTTP Cookie encoder and decoder written in pure Elixir with zero\ndependencies.\n\nFollows the standards for cookie headers described in MDN:\nhttps://developer.mozilla.org/en-US/docs/Web/HTTP/Cookies","ref":"CookieMonster.html"},{"type":"function","title":"CookieMonster.decode/1","doc":"Decodes a Set-Cookie header text into an Elixir struct\n\nSupports all valid expires date formats in the following spec standards:\n- RFC 1123\n- RFC 850 (despite being deprecated it is still considered valid)\n  - This format does pose some Y2K concerns due to the use of a 2-digit year\n    representation\n- ANSI C `asctime()` format\n\nFor more info see: https://www.rfc-editor.org/rfc/rfc2616#section-3.3.1","ref":"CookieMonster.html#decode/1"},{"type":"function","title":"Returns - CookieMonster.decode/1","doc":"When successful, an `{:ok, cookie}` tuple where `cookie` is a struct representation of the\ncookie string.\n\nOtherwise, returns an `{:error, atom}`, consult the types for more info.","ref":"CookieMonster.html#decode/1-returns"},{"type":"function","title":"Examples - CookieMonster.decode/1","doc":"iex> header = \"id=a3fWa; Expires=Wed, 21 Oct 2015 07:28:00 GMT; Secure; HttpOnly\"\n    ...> {:ok, cookie} = CookieMonster.decode(header)\n    ...> cookie\n    %CookieMonster.Cookie{\n      value: \"a3fWa\",\n      expires: ~U[2015-10-21 07:28:00Z],\n      http_only: true,\n      name: \"id\",\n      secure: true\n    }","ref":"CookieMonster.html#decode/1-examples"},{"type":"function","title":"CookieMonster.decode!/1","doc":"Decodes a Set-Cookie Header into an Elixir struct\n\nSimilar to `decode/1` except it will unwrap the error tuple and raise an\n`ArgumentError` in case of errors.","ref":"CookieMonster.html#decode!/1"},{"type":"function","title":"CookieMonster.encode/2","doc":"Encodes a cookie struct into a header string","ref":"CookieMonster.html#encode/2"},{"type":"function","title":"Arguments - CookieMonster.encode/2","doc":"- `cookie`: a string representation of a cookie\n- `opts`: an optional keyword list containing\n  - `target: :request` - build a cookie for use in a request (containing only\n     name and value pair)","ref":"CookieMonster.html#encode/2-arguments"},{"type":"function","title":"Returns - CookieMonster.encode/2","doc":"When successful, an `{:ok, cookie}` tuple where `cookie` is a string representation of the\ncookie. Dates are formatted using the [RFC 1123 spec](https://www.rfc-editor.org/rfc/rfc2616#section-3.3.1).\n\nOtherwise, returns an `{:error, atom}`, consult the types for more info.","ref":"CookieMonster.html#encode/2-returns"},{"type":"function","title":"Examples - CookieMonster.encode/2","doc":"iex> cookie = %CookieMonster.Cookie{\n    ...>   name: \"id\",\n    ...>   value: \"a3fWa\",\n    ...>   expires: ~U[2015-10-21 07:28:00Z],\n    ...>   http_only: true,\n    ...>   secure: true\n    ...> }\n    iex> CookieMonster.encode(cookie)\n    {:ok, \"id=a3fWa; Expires=Wed, 21 Oct 2015 07:28:00 GMT; HttpOnly; Secure\"}\n\n\n    iex> cookie = %CookieMonster.Cookie{\n    ...>   name: \"id\",\n    ...>   value: \"a3fWa\",\n    ...>   expires: ~U[2015-10-21 07:28:00Z],\n    ...>   http_only: true,\n    ...>   secure: true\n    ...> }\n    iex> CookieMonster.encode(cookie, target: :request)\n    {:ok, \"id=a3fWa\"}","ref":"CookieMonster.html#encode/2-examples"},{"type":"function","title":"CookieMonster.encode!/2","doc":"Similar to `encode/2`, but an `ArgumentError` exception is raised\nif the cookie cannot be encoded.","ref":"CookieMonster.html#encode!/2"},{"type":"module","title":"CookieMonster.Cookie","doc":"Data Structure for representing a cookie in Elixir","ref":"CookieMonster.Cookie.html"},{"type":"type","title":"CookieMonster.Cookie.t/0","doc":"","ref":"CookieMonster.Cookie.html#t:t/0"},{"type":"module","title":"CookieMonster.Decoder","doc":"Private module for decoding a cookie string. Please use\n`CookieMonster.decode/1` instead.","ref":"CookieMonster.Decoder.html"},{"type":"type","title":"CookieMonster.Decoder.err_t/0","doc":"","ref":"CookieMonster.Decoder.html#t:err_t/0"},{"type":"type","title":"CookieMonster.Decoder.ok_t/0","doc":"","ref":"CookieMonster.Decoder.html#t:ok_t/0"},{"type":"type","title":"CookieMonster.Decoder.return_t/0","doc":"","ref":"CookieMonster.Decoder.html#t:return_t/0"},{"type":"module","title":"CookieMonster.Encoder","doc":"Private module for decoding a cookie string. Please use\n`CookieMonster.encode/2` instead.","ref":"CookieMonster.Encoder.html"},{"type":"type","title":"CookieMonster.Encoder.return_t/0","doc":"","ref":"CookieMonster.Encoder.html#t:return_t/0"},{"type":"extras","title":"CookieMonster","doc":"# CookieMonster\n\n![Build Status](https://github.com/dkarter/cookie_monster/actions/workflows/elixir.yml/badge.svg) [![Hex.pm](https://img.shields.io/hexpm/v/cookie_monster)](https://hex.pm/packages/cookie_monster)\n\nA simple HTTP Cookie encoder and decoder in pure Elixir with zero runtime dependencies![^1].\n\n![cookie monster logo](https://github.com/dkarter/cookie_monster/raw/main/img/cookie_monster.png)","ref":"readme.html"},{"type":"extras","title":"Motivation - CookieMonster","doc":"I recently worked on an app that needed to parse cookies. Initially I reached\nout for [Plug](https://hex.pm/packages/plug)'s implementation to encode\nand decode the cookies, but that meant bringing in a (relatively) large dependency just to use a small portion of it (my application was not web facing).\n\nAnother issue I had with Plug's implementation is that it used the name of the cookie as a map key in the decoding result:\n\n```elixir\n\"hello=a3fWa; Expires=Wed, 21 Oct 2015 07:28:00 GMT; HttpOnly; Secure\"\n|> Plug.Conn.Cookies.decode()\n\n# => %{\"Expires\" => \"Wed, 21 Oct 2015 07:28:00 GMT\", \"hello\" => \"a3fWa\"}\n```\n\nI wanted something a little simpler, and dependency free that makes it easy to extract the name and\nvalue. As a bonus, I wanted to decode the date into an Elixir native DateTime\nso that I can easily check if a cookie is expired.","ref":"readme.html#motivation"},{"type":"extras","title":"Example - CookieMonster","doc":"##","ref":"readme.html#example"},{"type":"extras","title":"Encoding - CookieMonster","doc":"```elixir\nalias CookieMonster.Cookie\n\n%Cookie{\n  name: \"id\",\n  value: \"a3fWa\",\n  expires: ~U[2015-10-21 07:28:00Z],\n  http_only: true,\n  secure: true\n}\n|> CookieMonster.encode!()\n\n# => \"id=a3fWa; Expires=Wed, 21 Oct 2015 07:28:00 GMT; HttpOnly; Secure\"\n```\n\n##","ref":"readme.html#encoding"},{"type":"extras","title":"Decoding - CookieMonster","doc":"```elixir\nalias CookieMonster.Cookie\n\n\"id=a3fWa; Expires=Wed, 21 Oct 2015 07:28:00 GMT; HttpOnly; Secure\"\n|> CookieMonster.decode!()\n\n# => %Cookie{name: \"id\", value: \"a3fWa\", expires: ~U[2015-10-21 07:28:00Z], http_only: true, secure: true}\n```","ref":"readme.html#decoding"},{"type":"extras","title":"Installation - CookieMonster","doc":"The package can be installed by adding `cookie_monster` to your list of\ndependencies in `mix.exs`:\n\n \n\n```elixir\ndef deps do\n  [\n    {:cookie_monster, \"~> 1.1.5\"}\n  ]\nend\n```\n\n \n\nThe docs can be found at [https://hexdocs.pm/cookie_monster](https://hexdocs.pm/cookie_monster).\n\n[^1]: Boundary is listed as a dependency, but it is not a runtime dependency and only used during compile time to ensure proper design","ref":"readme.html#installation"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [1.1.5](https://github.com/dkarter/cookie_monster/compare/v1.1.4...v1.1.5) (2023-10-19)\n\n\n#","ref":"changelog.html"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* accept short weekday format for weekday names ([#16](https://github.com/dkarter/cookie_monster/issues/16)) ([fd83cc1](https://github.com/dkarter/cookie_monster/commit/fd83cc1b0a9b371d8beb47af54ba72996e4d35f7))\n\n## [1.1.4](https://github.com/dkarter/cookie_monster/compare/v1.1.3...v1.1.4) (2023-10-15)\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* cookie type max_age was incorrect ([c5de17f](https://github.com/dkarter/cookie_monster/commit/c5de17f2f787fffb9507a3b96f374c661b9f1c0a))\n* correctly document private modules ([f767ec8](https://github.com/dkarter/cookie_monster/commit/f767ec837eec23a062998aca56e1572188fd5959))\n* parse max_age to integer correctly ([0ada60c](https://github.com/dkarter/cookie_monster/commit/0ada60cc33c810d1427a87210d7ab003b30faa4e))\n\n## [1.1.3](https://github.com/dkarter/cookie_monster/compare/v1.1.2...v1.1.3) (2023-10-15)\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Miscellaneous Chores - Changelog","doc":"* release 1.1.3 ([90dece7](https://github.com/dkarter/cookie_monster/commit/90dece7d71bf009e81425c2d53e29110b5bc9b69))\n\n## [1.1.2](https://github.com/dkarter/cookie_monster/compare/v1.1.1...v1.1.2) (2023-10-15)\n\n\n#","ref":"changelog.html#miscellaneous-chores"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* automatically publish docs with hex package ([af3c87d](https://github.com/dkarter/cookie_monster/commit/af3c87ddf943eb2efbc31eb7dba1bece1479cc4b))\n\n## [1.1.1](https://github.com/dkarter/cookie_monster/compare/v1.1.0...v1.1.1) (2023-10-15)\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* support dashes in expiration format RFC1123 ([#10](https://github.com/dkarter/cookie_monster/issues/10)) ([81e081a](https://github.com/dkarter/cookie_monster/commit/81e081ab5b45a7da866b02436e90aea11668c83b))\n\n## [1.1.0](https://github.com/dkarter/cookie_monster/compare/v1.0.0...v1.1.0) (2023-10-15)\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Features - Changelog","doc":"* add support for all valid expiration datetime formats ([#8](https://github.com/dkarter/cookie_monster/issues/8)) ([d0c17f7](https://github.com/dkarter/cookie_monster/commit/d0c17f7cbf6fd92caf234f9807be0e81dd39ee4a))","ref":"changelog.html#features"},{"type":"extras","title":"1.0.0 (2023-10-15) - Changelog","doc":"#","ref":"changelog.html#1-0-0-2023-10-15"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* failing test due to Elixir version upgrade ([532852b](https://github.com/dkarter/cookie_monster/commit/532852b3cd65b5687f8efe5fa9a1d4114a1a4999))\n* return ArgumentError from `encode!` or `decode!` ([4f2d460](https://github.com/dkarter/cookie_monster/commit/4f2d46010544adf069aa0ee7904de14284dad3cd))\n* use of deprecated day_of_week/3 ([11812e9](https://github.com/dkarter/cookie_monster/commit/11812e9e8b8a3ed92b4ce6dc8f13bba7cf4f2d84))","ref":"changelog.html#bug-fixes"}],"content_type":"text/markdown"}